#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: __init__.py 10439 2017-11-05 09:05:24Z Lavender $
#
# Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Lavender $
# $Date: 2017-11-05 17:05:24 +0800 (Sun, 05 Nov 2017) $
# $Revision: 10439 $

import os
import logging

from django.conf import settings

ROOT_DIR_PATH = os.path.abspath(
    os.path.join('.'))

if hasattr(settings, 'TEMPLATES'):
    TEMPLATES_DIR_PATH = settings.TEMPLATES[0]['DIRS'][0]
else:
    TEMPLATES_DIR_PATH = os.path.abspath(
        os.path.join('.', 'templates'))
    
if settings.DEBUG:
    if hasattr(settings, 'STATICFILES_DIRS'):
        STATIC_DIR_PATH = settings.STATICFILES_DIRS[0]
    else:
        STATIC_DIR_PATH = os.path.abspath(
            os.path.join('.', 'static'))
else:
    if hasattr(settings, 'STATIC_ROOT'):
        STATIC_DIR_PATH = settings.STATIC_ROOT
    else:
        STATIC_DIR_PATH = os.path.abspath(
            os.path.join('.', 'static'))
            
FIXTURES_DIR_PATH = os.path.abspath(
    os.path.join('.', 'fixtures'))
    
IMAGES_DIR_PATH = os.path.abspath(
    os.path.join('.', 'images')) 

PROJECT_MASHINES_DIR = os.path.join(
    ROOT_DIR_PATH, "BoilerplateProjects")

PROJECT_MASHINES_ZIP = os.path.join(
    os.path.dirname(os.path.abspath(__file__)), "ProjectMachine.zip")

def createLogger(name, fileHandlerName):
    logger = logging.getLogger(name)
    logger.setLevel(logging.DEBUG)
    handler = logging.StreamHandler()
    handler.setFormatter(
        logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
    logger.addHandler(handler)
    fileHandler = logging.FileHandler(fileHandlerName)
    fileHandler.setLevel(logging.WARNING)
    logger.addHandler(fileHandler)
    return logger
    